# import the libraries we will need
from datetime import datetime
from pprint import pprint
import uuid
import requests

# create a requests session with the authentication header
session = requests.Session()
session.headers["X-API-Key"] = YOUR_API_KEY

# get today's date formatted as yyyy-mm-dd
date = datetime.utcnow().strftime("%Y-%m-%d")
# perform the request
url = "https://sports-api.cloudbet.com/pub/v2/odds/fixtures"
response = session.get(url, params={"sport": "soccer", "date": date, "limit": "50"})
# extract the JSON response
response_data = response.json()
events = []
for competition in response_data["competitions"]:
    competition_name = competition["category"]["name"] + " - " + competition["name"]
    for event in competition["events"]:
        events.append({
            "id": event["id"],
            "name": event["name"],
            "competition": competition_name,
        })

# fetch the selections for each event
selections = []
for event in events:
    url = f"https://sports-api.cloudbet.com/pub/v2/odds/events/{event['id']}"
    print("Fetching odds for {competition} {name}".format_map(event))
    response = session.get(url, params={"markets": "soccer.match_odds"})
    response_data = response.json()
    event_selections = (
        response_data
        .get("markets", {})
        .get("soccer.match_odds", {})
        .get("submarkets", {})
        .get("period=ft", {})
        .get("selections", [])
    )
    for event_selection in event_selections:
        selections.append({
            "event_id": event["id"],
            "event": event["name"],
            "competition": event["competition"],
            "home": response_data["home"]["name"],
            "away": response_data["away"]["name"],
            "outcome": event_selection["outcome"],
            "price": event_selection["price"],
            "status": event_selection["status"],
        })

# keep only enabled selections for teams with odds over 10
long_odds_selections = [
    s for s in selections
    if s["outcome"] != "draw" and s["price"] > 10 and s["status"] == "SELECTION_ENABLED"
]

# place the bets
for selection in long_odds_selections:
    request_data = {
        "eventId": str(selection["event_id"]),
        "marketUrl": "soccer.match_odds/" + selection["outcome"],
        "currency": "PLAY_EUR",
        "price": str(selection["price"]),
        "stake": "0.5",
        "referenceId": str(uuid.uuid4()),
    }
    url = "https://sports-api.cloudbet.com/pub/v3/bets/place"
    response_data = session.post(url, json=request_data).json()
    print(
        "Bet on {team} @ {price} in {competition} - {event}: {bet_status}".format(
            **selection,
            team=selection[selection["outcome"]],
            bet_status=response_data["status"],
        )
    )
